@@ -17,7 +17,8 @@ import tox
 import tox.session
 from tox import venv
 from tox.config import parseconfig
-from tox.config.parallel import ENV_VAR_KEY as PARALLEL_ENV_VAR_KEY
+from tox.config.parallel import ENV_VAR_KEY_PRIVATE as PARALLEL_ENV_VAR_KEY_PRIVATE
+from tox.config.parallel import ENV_VAR_KEY_PUBLIC as PARALLEL_ENV_VAR_KEY_PUBLIC
 from tox.reporter import update_default_reporter
 from tox.venv import CreationConfig, VirtualEnv, getdigest
 
@@ -66,7 +67,12 @@ def check_os_environ_stable():
 
     to_clean = {
         k: os.environ.pop(k, None)
-        for k in {PARALLEL_ENV_VAR_KEY, str("TOX_WORK_DIR"), str("PYTHONPATH")}
+        for k in {
+            PARALLEL_ENV_VAR_KEY_PRIVATE,
+            PARALLEL_ENV_VAR_KEY_PUBLIC,
+            str("TOX_WORK_DIR"),
+            str("PYTHONPATH"),
+        }
     }
 
     yield
@@ -96,12 +102,12 @@ def check_os_environ_stable():
 
 @pytest.fixture(name="newconfig")
 def create_new_config_file(tmpdir):
-    def create_new_config_file_(args, source=None, plugins=()):
+    def create_new_config_file_(args, source=None, plugins=(), filename="tox.ini"):
         if source is None:
             source = args
             args = []
         s = textwrap.dedent(source)
-        p = tmpdir.join("tox.ini")
+        p = tmpdir.join(filename)
         p.write(s)
         tox.session.setup_reporter(args)
         with tmpdir.as_cwd():
@@ -177,7 +183,7 @@ class RunResult:
 
     def __repr__(self):
         res = "RunResult(ret={}, args={!r}, out=\n{}\n, err=\n{})".format(
-            self.ret, self.args, self.out, self.err
+            self.ret, self.args, self.out, self.err,
         )
         if six.PY2:
             return res.encode("UTF-8")
@@ -191,13 +197,13 @@ class RunResult:
         msg = self.output()
         assert self.ret == 0, msg
         if is_run_test_env:
-            assert any("  congratulations :)" == l for l in reversed(self.outlines)), msg
+            assert any("  congratulations :)" == line for line in reversed(self.outlines)), msg
 
     def assert_fail(self, is_run_test_env=True):
         msg = self.output()
         assert self.ret, msg
         if is_run_test_env:
-            assert not any("  congratulations :)" == l for l in reversed(self.outlines)), msg
+            assert not any("  congratulations :)" == line for line in reversed(self.outlines)), msg
 
 
 class ReportExpectMock:
@@ -210,7 +216,7 @@ class ReportExpectMock:
 
     def clear(self):
         self._index = -1
-        if six.PY3:
+        if not six.PY2:
             self.instance.reported_lines.clear()
         else:
             del self.instance.reported_lines[:]
@@ -227,8 +233,8 @@ class ReportExpectMock:
             newindex += 1
         raise LookupError(
             "looking for {!r}, no reports found at >={:d} in {!r}".format(
-                cat, self._index + 1, self.instance.reported_lines
-            )
+                cat, self._index + 1, self.instance.reported_lines,
+            ),
         )
 
     def expect(self, cat, messagepattern="*", invert=False):
@@ -245,14 +251,14 @@ class ReportExpectMock:
                 if fnmatch(lmsg, messagepattern):
                     if invert:
                         raise AssertionError(
-                            "found {}({!r}), didn't expect it".format(cat, messagepattern)
+                            "found {}({!r}), didn't expect it".format(cat, messagepattern),
                         )
                     return
         if not invert:
             raise AssertionError(
                 "looking for {}({!r}), no reports found at >={:d} in {!r}".format(
-                    cat, messagepattern, self._index + 1, self.instance.reported_lines
-                )
+                    cat, messagepattern, self._index + 1, self.instance.reported_lines,
+                ),
             )
 
     def not_expect(self, cat, messagepattern="*"):
@@ -291,7 +297,7 @@ def create_mocksession(request):
             self.report = ReportExpectMock()
 
         def _clearmocks(self):
-            if six.PY3:
+            if not six.PY2:
                 self._pcalls.clear()
             else:
                 del self._pcalls[:]
@@ -375,7 +381,7 @@ def initproj(tmpdir):
         base = tmpdir.join(name)
         src_root_path = _path_join(base, src_root)
         assert base == src_root_path or src_root_path.relto(
-            base
+            base,
         ), "`src_root` must be the constructed project folder or its direct or indirect subfolder"
 
         base.ensure(dir=1)
@@ -397,7 +403,7 @@ def initproj(tmpdir):
                 )
             """.format(
                         **locals()
-                    )
+                    ),
                 },
             )
         if not _filedefs_contains(base, filedefs, src_root_path.join(name)):
@@ -408,11 +414,11 @@ def initproj(tmpdir):
                         "__init__.py": textwrap.dedent(
                             '''
                 """ module {} """
-                __version__ = {!r}'''
+                __version__ = {!r}''',
                         )
                         .strip()
-                        .format(name, version)
-                    }
+                        .format(name, version),
+                    },
                 },
             )
         manifestlines = [
@@ -503,7 +509,7 @@ def mock_venv(monkeypatch):
         def readconfig(cls, path):
             if path.dirname.endswith("{}py".format(os.sep)):
                 return CreationConfig(
-                    base_resolved_python_md5=getdigest(sys.executable),
+                    base_resolved_python_sha256=getdigest(sys.executable),
                     base_resolved_python_path=sys.executable,
                     tox_version=tox.__version__,
                     sitepackages=False,
@@ -513,7 +519,7 @@ def mock_venv(monkeypatch):
                 )
             elif path.dirname.endswith("{}.package".format(os.sep)):
                 return CreationConfig(
-                    base_resolved_python_md5=getdigest(sys.executable),
+                    base_resolved_python_sha256=getdigest(sys.executable),
                     base_resolved_python_path=sys.executable,
                     tox_version=tox.__version__,
                     sitepackages=False,
@@ -577,7 +583,7 @@ def mock_venv(monkeypatch):
 def current_tox_py():
     """generate the current (test runners) python versions key
     e.g. py37 when running under Python 3.7"""
-    return "py{}".format("".join(str(i) for i in sys.version_info[0:2]))
+    return "{}{}{}".format("pypy" if tox.INFO.IS_PYPY else "py", *sys.version_info)
 
 
 def pytest_runtest_setup(item):
