@@ -47,10 +47,9 @@ except ImportError:
 
 
 hookimpl = tox.hookimpl
-"""DEPRECATED - REMOVE - left for compatibility with plugins importing from here.
+# DEPRECATED - REMOVE - left for compatibility with plugins importing from here.
+# Import hookimpl directly from tox instead.
 
-Import hookimpl directly from tox instead.
-"""
 
 WITHIN_PROVISION = os.environ.get(str("TOX_PROVISION")) == "1"
 
@@ -87,7 +86,7 @@ class Parser:
                 super(HelpFormatter, self).__init__(prog, max_help_position=35, width=190)
 
         self.argparser = argparse.ArgumentParser(
-            description="tox options", add_help=False, prog="tox", formatter_class=HelpFormatter
+            description="tox options", add_help=False, prog="tox", formatter_class=HelpFormatter,
         )
         self._testenv_attr = []
 
@@ -239,7 +238,7 @@ class InstallcmdOption:
     def postprocess(self, testenv_config, value):
         if "{packages}" not in value:
             raise tox.exception.ConfigError(
-                "'install_command' must contain '{packages}' substitution"
+                "'install_command' must contain '{packages}' substitution",
             )
         return value
 
@@ -299,7 +298,7 @@ def propose_configs(cli_config_file):
             from_folder = py.path.local(cli_config_file)
         else:
             print(
-                "ERROR: {} is neither file or directory".format(cli_config_file), file=sys.stderr
+                "ERROR: {} is neither file or directory".format(cli_config_file), file=sys.stderr,
             )
             return
     for basename in INFO.CONFIG_CANDIDATES:
@@ -320,7 +319,7 @@ def parse_cli(args, pm):
         raise SystemExit(0)
     interpreters = Interpreters(hook=pm.hook)
     config = Config(
-        pluginmanager=pm, option=option, interpreters=interpreters, parser=parser, args=args
+        pluginmanager=pm, option=option, interpreters=interpreters, parser=parser, args=args,
     )
     return config, option
 
@@ -391,11 +390,15 @@ class SetenvDict(object):
 @tox.hookimpl
 def tox_addoption(parser):
     parser.add_argument(
-        "--version", action="store_true", help="report version information to stdout."
+        "--version", action="store_true", help="report version information to stdout.",
     )
     parser.add_argument("-h", "--help", action="store_true", help="show help about options")
     parser.add_argument(
-        "--help-ini", "--hi", action="store_true", dest="helpini", help="show help about ini-names"
+        "--help-ini",
+        "--hi",
+        action="store_true",
+        dest="helpini",
+        help="show help about ini-names",
     )
     add_verbosity_commands(parser)
     parser.add_argument(
@@ -417,7 +420,7 @@ def tox_addoption(parser):
         help="show list of all defined environments (with description if verbose)",
     )
     parser.add_argument(
-        "-c", dest="configfile", help="config file name or directory with 'tox.ini' file."
+        "-c", dest="configfile", help="config file name or directory with 'tox.ini' file.",
     )
     parser.add_argument(
         "-e",
@@ -436,7 +439,7 @@ def tox_addoption(parser):
     )
     parser.add_argument("--notest", action="store_true", help="skip invoking test commands.")
     parser.add_argument(
-        "--sdistonly", action="store_true", help="only perform the sdist packaging activity."
+        "--sdistonly", action="store_true", help="only perform the sdist packaging activity.",
     )
     add_parallel_flags(parser)
     parser.add_argument(
@@ -473,7 +476,7 @@ def tox_addoption(parser):
         "(pip by default).",
     )
     parser.add_argument(
-        "-r", "--recreate", action="store_true", help="force recreation of virtual environments"
+        "-r", "--recreate", action="store_true", help="force recreation of virtual environments",
     )
     parser.add_argument(
         "--result-json",
@@ -514,14 +517,18 @@ def tox_addoption(parser):
         help="override sitepackages setting to True in all envs",
     )
     parser.add_argument(
-        "--alwayscopy", action="store_true", help="override alwayscopy setting to True in all envs"
+        "--alwayscopy",
+        action="store_true",
+        help="override alwayscopy setting to True in all envs",
     )
 
     cli_skip_missing_interpreter(parser)
     parser.add_argument("--workdir", metavar="PATH", help="tox working directory")
 
     parser.add_argument(
-        "args", nargs="*", help="additional arguments available to command positional substitution"
+        "args",
+        nargs="*",
+        help="additional arguments available to command positional substitution",
     )
 
     def _set_envdir_from_devenv(testenv_config, value):
@@ -597,8 +604,8 @@ def tox_addoption(parser):
                     warnings.warn(
                         "conflicting basepython version (set {}, should be {}) for env '{}';"
                         "resolve conflict or set ignore_basepython_conflict".format(
-                            proposed_version, implied_version, testenv_config.envname
-                        )
+                            proposed_version, implied_version, testenv_config.envname,
+                        ),
                     )
 
         return proposed_python
@@ -625,11 +632,11 @@ def tox_addoption(parser):
     )
 
     parser.add_testenv_attribute(
-        name="envtmpdir", type="path", default="{envdir}/tmp", help="venv temporary directory"
+        name="envtmpdir", type="path", default="{envdir}/tmp", help="venv temporary directory",
     )
 
     parser.add_testenv_attribute(
-        name="envlogdir", type="path", default="{envdir}/log", help="venv log directory"
+        name="envlogdir", type="path", default="{envdir}/log", help="venv log directory",
     )
 
     parser.add_testenv_attribute(
@@ -978,14 +985,14 @@ class TestenvConfig:
     def getsupportedinterpreter(self):
         if tox.INFO.IS_WIN and self.basepython and "jython" in self.basepython:
             raise tox.exception.UnsupportedInterpreter(
-                "Jython/Windows does not support installing scripts"
+                "Jython/Windows does not support installing scripts",
             )
         info = self.config.interpreters.get_info(envconfig=self)
         if not info.executable:
             raise tox.exception.InterpreterNotFound(self.basepython)
         if not info.version_info:
             raise tox.exception.InvocationError(
-                "Failed to get version_info for {}: {}".format(info.name, info.err)
+                "Failed to get version_info for {}: {}".format(info.name, info.err),
             )
         return info.executable
 
@@ -1034,7 +1041,7 @@ class ParseIni(object):
         context_name = getcontextname()
         if context_name == "jenkins":
             reader = SectionReader(
-                "tox:jenkins", self._cfg, prefix=prefix, fallbacksections=[fallbacksection]
+                "tox:jenkins", self._cfg, prefix=prefix, fallbacksections=[fallbacksection],
             )
             dist_share_default = "{toxworkdir}/distshare"
         elif not context_name:
@@ -1160,7 +1167,7 @@ class ParseIni(object):
                 "\n".join(
                     "{} failed with {} at {}".format(key, exc, trace)
                     for key, (exc, trace) in failures.items()
-                )
+                ),
             )
         for name in order:
             config.envconfigs[name] = results[name]
@@ -1189,7 +1196,7 @@ class ParseIni(object):
                 self._cfg.sections[section_name] = {}
             self._cfg.sections[section_name]["description"] = "meta tox"
             env_config = self.make_envconfig(
-                name, "{}{}".format(testenvprefix, name), reader._subs, config
+                name, "{}{}".format(testenvprefix, name), reader._subs, config,
             )
             env_config.deps = deps
             config.envconfigs[config.provision_tox_env] = env_config
@@ -1244,7 +1251,7 @@ class ParseIni(object):
             self._cfg.sections[section_name]["sitepackages"] = "False"
             self._cfg.sections[section_name]["description"] = "isolated packaging environment"
             config.envconfigs[name] = self.make_envconfig(
-                name, "{}{}".format(testenvprefix, name), reader._subs, config
+                name, "{}{}".format(testenvprefix, name), reader._subs, config,
             )
 
     def _list_section_factors(self, section):
@@ -1284,7 +1291,7 @@ class ParseIni(object):
                 elif atype == "basepython":
                     no_fallback = name in (config.provision_tox_env,)
                     res = reader.getstring(
-                        env_attr.name, env_attr.default, replace=replace, no_fallback=no_fallback
+                        env_attr.name, env_attr.default, replace=replace, no_fallback=no_fallback,
                     )
                 elif atype == "space-separated-list":
                     res = reader.getlist(env_attr.name, sep=" ")
@@ -1454,10 +1461,8 @@ class IndexServerConfig:
 
 
 is_section_substitution = re.compile(r"{\[[^{}\s]+\]\S+?}").match
-"""Check value matches substitution form of referencing value from other section.
-
-E.g. {[base]commands}
-"""
+# Check value matches substitution form of referencing value from other section.
+# E.g. {[base]commands}
 
 
 class SectionReader:
@@ -1545,7 +1550,7 @@ class SectionReader:
                 s = False
             else:
                 raise tox.exception.ConfigError(
-                    "{}: boolean value {!r} needs to be 'True' or 'False'".format(name, s)
+                    "{}: boolean value {!r} needs to be 'True' or 'False'".format(name, s),
                 )
         return s
 
@@ -1614,7 +1619,7 @@ class SectionReader:
             if not section_name.startswith(testenvprefix):
                 raise tox.exception.ConfigError(
                     "substitution env:{!r}: unknown or recursive definition in"
-                    " section {!r}.".format(value, section_name)
+                    " section {!r}.".format(value, section_name),
                 )
             raise
         return replaced
@@ -1676,7 +1681,7 @@ class Replacer:
             sub_type = g["sub_type"]
         except KeyError:
             raise tox.exception.ConfigError(
-                "Malformed substitution; no substitution type provided"
+                "Malformed substitution; no substitution type provided",
             )
 
         if sub_type == "env":
@@ -1687,7 +1692,7 @@ class Replacer:
             return match.group("default_value")
         if sub_type is not None:
             raise tox.exception.ConfigError(
-                "No support for the {} substitution type".format(sub_type)
+                "No support for the {} substitution type".format(sub_type),
             )
         return self._replace_substitution(match)
 
@@ -1711,11 +1716,11 @@ class Replacer:
             if section in cfg and item in cfg[section]:
                 if (section, item) in self.reader._subststack:
                     raise ValueError(
-                        "{} already in {}".format((section, item), self.reader._subststack)
+                        "{} already in {}".format((section, item), self.reader._subststack),
                     )
                 x = str(cfg[section][item])
                 return self.reader._replace(
-                    x, name=item, section_name=section, crossonly=self.crossonly
+                    x, name=item, section_name=section, crossonly=self.crossonly,
                 )
 
         raise tox.exception.ConfigError("substitution key {!r} not found".format(key))
@@ -1767,8 +1772,8 @@ class _ArgvlistReader:
             if current_command:
                 raise tox.exception.ConfigError(
                     "line-continuation ends nowhere while resolving for [{}] {}".format(
-                        reader.section_name, "commands"
-                    )
+                        reader.section_name, "commands",
+                    ),
                 )
         return commands
 
